<?php
/**
 * Plugin Name: JAKWEB Widget
 * Plugin URI: https://jakweb.ch/
 * Description: Display the Live Chat or HelpDesk Chat, FAQ, Support
 * Version: 1.0
 * Author: Jerome Kaegi
 * Author URI: https://jakweb.ch
 *
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 1.0
 */
add_action( 'widgets_init', 'jakweb_load_widgets' );

/**
 * Register our widget.
 * 'JAKWEB_LS' is the widget class used below.
 *
 * @since 1.0
 */
function jakweb_load_widgets() {
	register_widget( 'JAKWEB_LS' );
}

/**
 * JAKWEB Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 1.0
 */
class JAKWEB_LS extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'jakweb-widget', // Base ID
			'Embed Code - JAKWEB', // Name
			array( 'description' => 'Live Chat / FAQ / Support Embed Code' ) // Args
		);

	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$button = $instance['button'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		/* Display name from widget settings if one was input. */
		if ( $button )
			printf($button);

		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		/* No Strip Tags */
		$instance['button'] = $new_instance['button'];

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array('title' => __('Live Chat / FAQ / Support Embed Code', 'jakweb'), 'button' => __('', 'jakweb'));
		$instance = wp_parse_args((array) $instance, $defaults ); ?>
		
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'Live Chat / FAQ / Support Embed Code'); ?></label><br />
			<input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<!-- Your Button: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id('button'); ?>"><?php _e('Button Code:', ''); ?></label><br />
			<textarea id="<?php echo $this->get_field_id('button'); ?>" name="<?php echo $this->get_field_name('button'); ?>"><?php echo $instance['button']; ?></textarea>
		</p>

	<?php
	}
}

?>